@@ -411,7 +411,7 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
                 raise DownloadUserCertFailed(self.ip_address)
         return file_name
 
-    def restore_cert(self, password, file, restore_type="all"):
+    def restore_cert(self, password, file, restore_type="full"):
         params = {"password": password, "type": restore_type}
         response = self._post('/restorecert', file=file,
                               parameters=params)
